@@ -3,6 +3,10 @@
 
 XBase::Index - base class for the index files for dbf
 
+=head1 SYNOPSIS
+
+No synopsis yet, sorry.
+
 =head1 DESCRIPTION
 
 =head2 Proposal:
@@ -30,3 +34,9 @@ for updates where we need to rewrite the content of the index.
 
 =cut
 
+package XBase::Index::Page;
+
+
+
+1;
+
